# Generated by roxygen2: do not edit by hand

export(GENIE_maf_schema)
export(TCGA_maf_schema)
export(add)
export(al.pairwise.alteration.stats)
export(al.stats)
export(am.pairwise.alteration.coverage)
export(am.pairwise.alteration.overlap)
export(am.stats)
export(am.weight.pairwise.alteration.overlap)
export(binary.yule)
export(effectSize)
export(estimateFDR2)
export(estimate_p_val)
export(estimate_pairwise_p)
export(filter_maf_column)
export(filter_maf_complex)
export(filter_maf_gene.name)
export(filter_maf_ignore)
export(filter_maf_missense)
export(filter_maf_mutation.type)
export(filter_maf_mutations)
export(filter_maf_sample)
export(filter_maf_schema)
export(filter_maf_truncating)
export(generateS)
export(generateW_block)
export(generateW_mean_tmb)
export(get.blocks)
export(interaction.table)
export(maf2gam)
export(mutation_type)
export(new.AL.general)
export(new.ALS)
export(new.AMS)
export(null_model_parallel)
export(obs_exp_scatter)
export(overlap_pair_extract)
export(r.am.pairwise.alteration.overlap)
export(r.effectSize)
export(retrieveOutliers)
export(ridge_plot_ed)
export(ridge_plot_ed_compare)
export(selectX)
export(stat_maf_column)
export(stat_maf_gene)
export(stat_maf_sample)
export(template.obj.gen)
export(theme_Publication)
export(w.r.am.pairwise.alteration.overlap)
import(doParallel)
import(doRNG)
import(foreach)
import(ggplot2)
import(ggpubr)
import(ggridges)
importFrom(Matrix,Matrix)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,t)
importFrom(Rcpp,sourceCpp)
importFrom(Rfast,rowSort)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,ungroup)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(stats,as.dist)
importFrom(stats,density)
importFrom(stats,ecdf)
importFrom(stats,median)
importFrom(stats,runif)
importFrom(stats,setNames)
useDynLib(SelectSim, .registration = TRUE)
