#' Lung adenocarcinoma from TCGA cohort as SelectSim run object
#'
#' Preprocessed TCGA LUAD data ready to pass directly to \code{selectX()}.
#'
#' @docType data
#' @keywords datasets
#' @name luad_run_data
#' @usage data(luad_run_data)
#' @format A named list with four elements:
#' \describe{
#'   \item{M}{A named list containing:
#'     \describe{
#'       \item{M}{A named list of binary alteration matrices (genes x samples),
#'         one per alteration type (e.g., \code{missense}, \code{truncating}).}
#'       \item{tmb}{A named list of data frames, one per alteration type, each
#'         with columns \code{sample} (character) and \code{mutation} (integer
#'         TMB count).}
#'     }
#'   }
#'   \item{sample.class}{Named character vector of sample-type annotations
#'     (length = number of samples). Names are sample IDs.}
#'   \item{alteration.class}{Named character vector of alteration-type annotations
#'     (length = number of genes). Names are gene symbols.}
#' }
#'
#' @return A named list containing preprocessed LUAD input data for
#'   \code{selectX()}.
#' @examples
#' data(luad_run_data)
#' names(luad_run_data)
#' str(luad_run_data, max.level = 1)
NULL


#' Lung adenocarcinoma from TCGA cohort as SelectSim run results
#'
#' Result of LUAD generated by SelectSim with SelectSim run done at min.freq=10.
#'
#'
#' @docType data
#' @keywords datasets
#' @name luad_result
#' @usage data(luad_result)
#' @format A data frame
#'
#' @return A data frame containing SelectSim results for the LUAD cohort.
#' @examples
#' data(luad_result)
#' dim(luad_result)
#' head(luad_result)
NULL



#' Lung adenocarcinoma MAF from TCGA cohort 
#'
#' MAF file of LUAD from TCGA
#'
#'
#' @docType data
#' @keywords datasets
#' @name luad_maf
#' @usage data(luad_maf)
#' @format A data frame
#'
#' @return A data frame containing TCGA LUAD mutation data.
#' @examples
#' data(luad_maf)
#' dim(luad_maf)
#' head(luad_maf)
NULL


#' OncoKB v3.9 cancer genes
#'
#' cancer genes list
#'
#'
#' @docType data
#' @keywords datasets
#' @name oncokb_genes
#' @usage data(oncokb_genes)
#' @format A list
#'
#' @return An object containing cancer-associated genes annotated by OncoKB.
#' @examples
#' data(oncokb_genes)
#' length(oncokb_genes)
#' head(oncokb_genes)
NULL


#' OncoKB v3.9 cancer genes consider for truncating mutations
#'
#' cancer genes list consider for truncating mutations
#'
#'
#' @docType data
#' @keywords datasets
#' @name oncokb_truncating_genes
#' @usage data(oncokb_truncating_genes)
#' @format A list
#'
#' @return An object containing genes considered for truncating-mutation analyses.
#' @examples
#' data(oncokb_truncating_genes)
#' length(oncokb_truncating_genes)
#' head(oncokb_truncating_genes)
NULL


#' OncoKB v3.9 cancer genes
#'
#' A dataframe cancer genes with missense mutation annotations
#'
#'
#' @docType data
#' @keywords datasets
#' @name variant_catalogue
#' @usage data(variant_catalogue)
#' @format A data frame
#'
#' @return A data frame containing cancer-gene and variant annotations.
#' @examples
#' data(variant_catalogue)
#' dim(variant_catalogue)
#' head(variant_catalogue)
NULL
