# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

rcpp_overlap <- function(v, t = 1L) {
    .Call(`_SelectSim_rcpp_overlap`, v, t)
}

rcpp_w_overlap <- function(v, w, t = 1L) {
    .Call(`_SelectSim_rcpp_w_overlap`, v, w, t)
}

