% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{am.weight.pairwise.alteration.overlap}
\alias{am.weight.pairwise.alteration.overlap}
\title{Compute TMB-weighted pairwise alteration overlap}
\usage{
am.weight.pairwise.alteration.overlap(am, W)
}
\arguments{
\item{am}{Binary alteration matrix (features x samples)}

\item{W}{Weight matrix (features x samples) with per-sample TMB weights}
}
\value{
Weighted pairwise overlap matrix (features x features).
}
\description{
Compute TMB-weighted pairwise alteration overlap
}
\examples{
am <- matrix(c(0,1,1,0,1,1), nrow = 2,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
W  <- matrix(1, nrow = 2, ncol = 3,
             dimnames = list(c("geneA","geneB"), c("s1","s2","s3")))
am.weight.pairwise.alteration.overlap(am, W)

}
