% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_create.r
\name{template.obj.gen}
\alias{template.obj.gen}
\title{Generate the template matrix}
\usage{
template.obj.gen(al)
}
\arguments{
\item{al}{Alteration landscape object}
}
\value{
A list with \code{template.obj} (per-block S matrices) and
\code{temp_mat} (full concatenated template matrices, one per GAM type).
}
\description{
Computes the expected mutation probability matrices (one per GAM type, per
sample block) used as the simulation background in \code{null_model_parallel}.
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
al <- new.AL.general(luad_run_data$M,
                     feat.covariates  = luad_run_data$alteration.class,
                     sample.covariates = luad_run_data$sample.class,
                     min.freq = 10)
template.obj.gen(al)
}

}
