% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/selectX_stats.r
\name{al.pairwise.alteration.stats}
\alias{al.pairwise.alteration.stats}
\title{Compute pairwise alteration statistics for an alteration landscape}
\usage{
al.pairwise.alteration.stats(al, als = NULL, do.blocks = FALSE)
}
\arguments{
\item{al}{SelectX object (list containing al, W, etc.)}

\item{als}{Alteration landscape stats (from al.stats); computed internally if NULL}

\item{do.blocks}{Whether to also compute block-level pairwise stats}
}
\value{
List with overlap and w_overlap matrices, plus optional sample.blocks entries.
}
\description{
Compute pairwise alteration statistics for an alteration landscape
}
\examples{
\donttest{
data(luad_run_data, package = "SelectSim")
result <- selectX(M = luad_run_data$M,
                  sample.class = luad_run_data$sample.class,
                  alteration.class = luad_run_data$alteration.class,
                  n.cores = 1, min.freq = 10, n.permut = 10,
                  verbose = FALSE)
al.pairwise.alteration.stats(result$obj)
}

}
